@@ -107,6 +107,15 @@ class ArgoVar:
     def __repr__(self):
         return self.expr
 
+    def __getitem__(self, i):
+        if isinstance(i, str):
+            return ArgoVar("jsonpath(%s, '$')['%s']" % (self.expr, i))
+        else:
+            return ArgoVar("jsonpath(%s, '$')[%s]" % (self.expr, i))
+
+    def __iter__(self):
+        raise TypeError("'ArgoVar' object is not iterable")
+
     def __eq__(self, other):
         if isinstance(other, ArgoVar):
             other = other.expr
