@@ -157,7 +157,7 @@ class Step:
             key: str = None,
             executor: Executor = None,
             use_resource: Resource = None,
-            util_image: str = "python:3.8",
+            util_image: str = None,
             util_command: Union[str, List[str]] = None,
             **kwargs,
     ) -> None:
@@ -186,6 +186,8 @@ class Step:
         self.key = key
         self.executor = executor
         self.use_resource = use_resource
+        if util_image is None:
+            util_image = config["util_image"]
         self.util_image = util_image
         if isinstance(util_command, str):
             util_command = [util_command]
@@ -233,19 +235,30 @@ class Step:
                     value=re.sub("{{item.*}}", "group", str(self.key)))
                 init_template.inputs.parameters["dflow_group_key"] = \
                     InputParameter()
-
-            init_template.outputs.parameters["dflow_artifact_key"] = \
-                OutputParameter(value="{{workflow.name}}/{{pod.name}}")
-            new_template.inputs.parameters["dflow_artifact_key"] = \
-                InputParameter(value="")
-            for name in new_template.slices.output_artifact:
-                init_template.outputs.artifacts[name] = OutputArtifact(
-                    path="/tmp/outputs/artifacts/%s" % name,
-                    save=S3Artifact(key="{{workflow.name}}/{{pod.name}}/%s"
-                                    % name), archive=None)
-                new_template.outputs.artifacts[name].save.append(
-                    S3Artifact(key="{{inputs.parameters."
-                               "dflow_artifact_key}}/%s" % name))
+                # For the case of reusing sliced steps, ensure that the output
+                # artifacts are reused
+                for name in new_template.slices.output_artifact:
+                    init_template.outputs.artifacts[name] = OutputArtifact(
+                        path="/tmp/outputs/artifacts/%s" % name,
+                        save=S3Artifact(key="{{workflow.name}}/{{inputs."
+                                        "parameters.dflow_group_key}}/%s"
+                                        % name), archive=None)
+                    new_template.outputs.artifacts[name].save.append(
+                        S3Artifact(key="{{workflow.name}}/{{inputs."
+                                   "parameters.dflow_group_key}}/%s" % name))
+            else:
+                init_template.outputs.parameters["dflow_artifact_key"] = \
+                    OutputParameter(value="{{workflow.name}}/{{pod.name}}")
+                new_template.inputs.parameters["dflow_artifact_key"] = \
+                    InputParameter(value="")
+                for name in new_template.slices.output_artifact:
+                    init_template.outputs.artifacts[name] = OutputArtifact(
+                        path="/tmp/outputs/artifacts/%s" % name,
+                        save=S3Artifact(key="{{workflow.name}}/{{pod.name}}/%s"
+                                        % name), archive=None)
+                    new_template.outputs.artifacts[name].save.append(
+                        S3Artifact(key="{{inputs.parameters."
+                                   "dflow_artifact_key}}/%s" % name))
 
             if new_template.slices.sub_path and \
                     new_template.slices.input_artifact:
@@ -301,9 +314,10 @@ class Step:
                     name="%s-init-artifact" % self.name,
                     template=init_template)
 
-            self.inputs.parameters["dflow_artifact_key"] = InputParameter(
-                value=self.prepare_step.outputs.parameters[
-                    "dflow_artifact_key"])
+            if key is None:
+                self.inputs.parameters["dflow_artifact_key"] = InputParameter(
+                    value=self.prepare_step.outputs.parameters[
+                        "dflow_artifact_key"])
 
             if new_template.slices.sub_path and \
                     new_template.slices.input_artifact:
